@@ -671,7 +671,7 @@ GMManager::OnForwarded (OpalConnection &,
   gnomemeeting_threads_enter ();
   msg = g_strdup_printf (_("Forwarding call to %s"),
 			 (const char*) forward_party);
-  gm_main_window_flash_message (main_window, msg);
+  gm_main_window_flash_message (main_window, "%s", msg);
   gm_history_window_insert (history_window, msg);
   gnomemeeting_threads_leave ();
   g_free (msg);
@@ -825,7 +825,7 @@ GMManager::OnIncomingConnection (OpalConnection &connection,
   /* Update the log and status bar */
   msg = g_strdup_printf (_("Call from %s"), (const char *) utf8_name);
   gnomemeeting_threads_enter ();
-  gm_main_window_flash_message (main_window, msg);
+  gm_main_window_flash_message (main_window, "%s", msg);
   gm_chat_window_push_info_message (chat_window, NULL, msg);
   gm_history_window_insert (history_window, msg);
   gnomemeeting_threads_leave ();
@@ -865,7 +865,7 @@ GMManager::OnIncomingConnection (OpalConnection &connection,
   /* Display the action message */
   gnomemeeting_threads_enter ();
   if (short_reason) 
-    gm_main_window_flash_message (main_window, short_reason);
+    gm_main_window_flash_message (main_window, "%s", short_reason);
   if (long_reason)
     gm_history_window_insert (history_window, long_reason);
   gnomemeeting_threads_leave ();
@@ -1013,7 +1013,7 @@ GMManager::OnEstablished (OpalConnection &connection)
 			      utf8_name, utf8_app);
   msg = g_strdup_printf (_("Connected with %s"), utf8_name);
   gm_main_window_set_status (main_window, msg);
-  gm_main_window_flash_message (main_window, msg);
+  gm_main_window_flash_message (main_window, "%s", msg);
   gm_chat_window_push_info_message (chat_window, NULL, msg);
   gm_main_window_update_calling_state (main_window, GMManager::Connected);
   gm_chat_window_update_calling_state (chat_window, 
@@ -1290,7 +1290,7 @@ GMManager::OnReleased (OpalConnection & connection)
 				 msg_reason,
 				 utf8_app);
   gm_history_window_insert (history_window, msg_reason);
-  gm_main_window_flash_message (main_window, msg_reason);
+  gm_main_window_flash_message (main_window, "%s", msg_reason);
   gm_chat_window_push_info_message (chat_window, NULL, "");
   gnomemeeting_threads_leave ();
 
